<template>
    <div>
        <address-form 
            v-if="add_new_delivery_address"
            :editmode="address_edit_mode"
            :addnew="add_new_delivery_address"
            :order="order"
            :address="address"
            type="delivery"
            :show_invoice_notice="true"
            :delivery_form_alert="delivery_form_alert"
        ></address-form>

        <address-form 
            v-if="add_new_invoice_address"
            :editmode="address_edit_mode"
            :addnew="add_new_invoice_address"
            :order="order"
            :address="address"
            type="billing"
            :invoice_form_alert="invoice_form_alert"
        ></address-form>

        <address-list 
            :address_list="address_list" 
            :order="order" :type="address_type" 
            :addresses="addresses"
        ></address-list>

        <login-screen 
            :order="order" 
            :show="login_screen" 
            alert_message="Please login to continue"
        ></login-screen>

        <register-screen 
            :order="order" 
            :register="register_screen" 
            alert_message="Please Register to continue"
        ></register-screen>

        <v-progress-circular
        v-if="loading"
        :size="70"
        :width="2"
        color="#525252"
        class="_loadingi"
        indeterminate
        ></v-progress-circular>
        <div v-if="empty_cart && !loading">
            <div class="_empty_cart">
                <img src="~/assets/img/blank2.svg" alt="">

                <div class="_content">
                    <div class="_head">Your cart is empty</div>
                    <p>Looks like you haven't added any wires to your cart yet.</p>
                    <v-btn to="/" color="#da3327" outline large>Shop Wires</v-btn>
                </div>
            </div>
        </div>
        <div v-if="!empty_cart && !loading && !step && !login_screen">
            <checkout-screen
            :order_data="order_data"
            :login_screen="login_screen"
            :order="order"
            :address_list="address_list"
            :addresses="addresses">
           </checkout-screen>
        </div>
    </div>
</template>
<script>
import axios from 'axios';
import Vue from 'vue';
import AddressForm from '~/components/AddressForm.vue';
import AddressList from '~/components/AddressList.vue';
import LoginScreen from '~/components/LoginScreen.vue';
import RegisterScreen from '~/components/RegisterScreen.vue';
import CheckoutScreen from '~/components/CheckoutScreen.vue';

Vue.component('address-form', AddressForm);
Vue.component('address-list', AddressList);
Vue.component('login-screen', LoginScreen);
Vue.component('register-screen', RegisterScreen);
Vue.component('checkout-screen', CheckoutScreen);

export default {
    layout: 'checkout',
    data () {
        return {
            address_edit_mode: false,
            order: this,
            step: null,
            loading: true,
            login_screen: false,
            register_screen: false,
            empty_cart: false,
            add_new_delivery_address: false,
            add_new_invoice_address: false,
            address_list: false,
            address_type: null,
            delivery_form_alert: null,
            invoice_form_alert: null,
            address: {
                id_state: +33
            },
            addresses: [],
            invoice_address: null,
            delivery_address: null,
            order_data: []
        }
    },
    created () {
        this.checkOrderProcess();
    },
    methods: {
        checkOrderProcess: function () {
            this.loading = true;
            axios.get(this.$store.state.api_domain + '?comp=process&action=checkOrderProcess', {withCredentials: true}).then((res) => {
                if (res.data.status == 'success') {
                    this.order_data = res.data;
                    this.add_new_delivery_address = false;
                    this.add_new_invoice_address = false;
                    this.register_screen = false;
                    this.address_type = '';

                    if (!res.data.auth) {
                        this.loading = false;
                        this.$router.push('/account/login?back=order');
                    }

                    if (!this.login_screen) {
                        this.loading = false;
                    }

                    if (res.data.empty_cart) {
                      this.empty_cart = true;
                    } else if (res.data.auth) {
                        if (res.data.cart) {
                            this.$store.commit('setCart', res.data.cart);
                        }

                        if (res.data.step == 'add_delivery_address') {
                            this.address_type = 'delivery';
                            if (res.data.chooseAddress == 'addressList') {
                                this.address_list = true;
                            } else {
                                this.address = [];
                                this.add_new_delivery_address = true;
                            }
                        }

                        if (res.data.step == 'add_invoice_address') {
                            this.address_type = 'invoice';
                            if (
                              res.data.chooseAddress == 'addressList' &&
                              res.data.available_addresses_count > 1
                            ) {
                                this.address_list = true;
                            } else {
                              // this.invoice_form_alert = 'Please add invoice address in order to continue.';
                              this.address = [];
                              this.add_new_invoice_address = true;
                            }
                        }

                        this.addresses = res.data.addresses;
                        this.delivery_address = res.data.delivery_address;
                        this.invoice_address = res.data.invoice_address;

                        if (res.data.customer) {
                          this.$store.commit('setCustomer', res.data.customer);
                        }
                    }
                }

                if (res.data.status == 'broker') {
                    this.$router.push('broker/dashboard?back=order');
                }
            });
        }
    },
    head () {
        return {
            title: 'Order Wires | Balingwiredirect.com',
            meta: [
                {hid: 'description', name: 'description', content: 'Checkout screen'},
                {hid: 'keywords', name: 'keywords', content: 'order checkout'}
            ]
        }
    }
}
</script>
